.. _trojanvision.defenses.backdoor.attack_agnostic:

attack_agnostic
================

.. currentmodule:: trojanvision.defenses

.. autoclass:: AdvTrain
    :members:

.. autoclass:: FinePruning
    :members:

.. autoclass:: MagNet
    :members:

.. autoclass:: RandomizedSmooth
    :members:

.. autoclass:: Recompress
    :members:
